*** THIS DO-FILE REPRODUCES ALL OF THE TABLES AND FIGURES IN ONLINE APPENDIX B AND C ***

*** USE THE SWEDISH ADMINISTRATIVE DATA DESCRIBED IN THE READ ME FILE ***

/* 
We use a new spell length variable when doing graphs, which is censored at 60 weeks. 
This is made in order to have the graph to be ended within a reasonable time frame being relevant for the experiment. 
We use both Cox and PCE (piecewise constant exponential) regression models. They produce similar estimates for the x's being included.

Occupational codes in SSYK

High skilled occupations

1. Computer occupations, 213
2. Accountants and auditors, 343
3. Registered nurses, 223, 323
4. Middle school teachers, 233, 234
5. Secondary school teachers, 232

Low and medium skilled occupations *
6. Sales representatives and buying and purchasing agents, 341
7. Retail sales persons and cashiers, 522
8. Installation, maintenance and repair occupations, 723, 724
9. Construction laborers and carpenters, 712
10. Bus, truck and taxi drivers, 832
11. Janitors and cleaners, 912
12. Food serving and waitress, 512, 913
*/

gen occ05=0
replace occ05=6 if ssyk3_bas05>=1 & ssyk3_bas05<=399
replace occ05=14 if ssyk3_bas05>=400
replace occ05=1 if ssyk3_bas05==213
replace occ05=2 if ssyk3_bas05==343
replace occ05=3 if ssyk3_bas05==223
replace occ05=3 if ssyk3_bas05==323
replace occ05=4 if ssyk3_bas05==233
replace occ05=4 if ssyk3_bas05==234
replace occ05=5 if ssyk3_bas05==232
replace occ05=7 if ssyk3_bas05==341
replace occ05=8 if ssyk3_bas05==522
replace occ05=9 if ssyk3_bas05==723
replace occ05=9 if ssyk3_bas05==724
replace occ05=10 if ssyk3_bas05==712
replace occ05=11 if ssyk3_bas05==832
replace occ05=12 if ssyk3_bas05==912
replace occ05=13 if ssyk3_bas05==913
replace occ05=13 if ssyk3_bas05==512

label define occ05 1 "Comp spec" 2 "Accountants" 3 "Nurses" 4 "Middle school" 5 "Sec school" 6 All other high skill 7 "Sales reps" 8 "Retail sale" 9 "Repair occ" 10 "Construction" 11 "Truck drivers" 12 "Cleaners" 13 "Serving" 14 All other med/low skill

/*
Coding of ALL occupations into high vs medium/low skill
Using SSYK<=399 as the definition of high skilled
*/

gen occ05_high=0
replace occ05_high=1 if ssyk3_bas05==213
replace occ05_high=1 if ssyk3_bas05==343
replace occ05_high=1 if ssyk3_bas05==223
replace occ05_high=1 if ssyk3_bas05==323
replace occ05_high=1 if ssyk3_bas05==233
replace occ05_high=1 if ssyk3_bas05==234
replace occ05_high=1 if ssyk3_bas05==232

replace occ05_high=2 if ssyk3_bas05==341
replace occ05_high=2 if ssyk3_bas05==522
replace occ05_high=2 if ssyk3_bas05==723
replace occ05_high=2 if ssyk3_bas05==724
replace occ05_high=2 if ssyk3_bas05==712
replace occ05_high=2 if ssyk3_bas05==832
replace occ05_high=2 if ssyk3_bas05==912
replace occ05_high=2 if ssyk3_bas05==913
replace occ05_high=2 if ssyk3_bas05==512

* Create occupational levels to be used in Kaplan-Meier estimates

gen occ_lev=1 if ssyk3_bas05>=1 & ssyk3_bas05<=399
replace occ_lev=2 if occ05_high==1
replace occ_lev=3 if ssyk3_bas05>=400
replace occ_lev=4 if occ05_high==2

label define occ_lev 0 "missing" 1 "High_other" 2 "High_in_experiment" 3 "LowMid_other" 4 "LowMid_in_experiment"

* Construction of (some) X's

gen age=2005-birthyear
gen male=male=1 if kon==1
gen punemp_month=punemp_weeks/4
replace punemp_spells=10 if punemp_spells>=10

* Table B1: Descriptives by occupation

tab occ05 if age>=23 & age<=32 
bysort occ05: summ male age education2003 employed if age>=23 & age<=32
summ punemp_weeks punemp_spells if age>=23 & age<=32

* Table B2

/*
The aim is to present numbers showing that the data could be interpreted as being produced by duration dependence, that is, a declining hazard "rate". We decided upon using the PCE model producing estimates of the hazard rate for each interval and corresponding SE's. 

i) create a new id being unique for each spell 
*/

gen t = _n
stset spell_weeks, failure(employed==1) id(t)

/*
ii) we use the time periods of 0-<3, 3-<6, 6-<9, 9-<12, 12- months (data in weeks).
*/

stpiece if age>=23 & age<=32 & occ_lev==1, tp(0 11 23 35 47)
stpiece if age>=23 & age<=32 & occ_lev==2, tp(0 11 23 35 47)
stpiece if age>=23 & age<=32 & occ_lev==3, tp(0 11 23 35 47)
stpiece if age>=23 & age<=32 & occ_lev==4, tp(0 11 23 35 47)

* Table B3 (same as Table B2, but by occupation)

stpiece if age>=23 & age<=32 & occ05==1, tp(0 11 23 35 47)
stpiece if age>=23 & age<=32 & occ05==2, tp(0 11 23 35 47)
stpiece if age>=23 & age<=32 & occ05==3, tp(0 11 23 35 47)
stpiece if age>=23 & age<=32 & occ05==4, tp(0 11 23 35 47)
stpiece if age>=23 & age<=32 & occ05==5, tp(0 11 23 35 47)
stpiece if age>=23 & age<=32 & occ05==7, tp(0 11 23 35 47)
stpiece if age>=23 & age<=32 & occ05==8, tp(0 11 23 35 47)
stpiece if age>=23 & age<=32 & occ05==9, tp(0 11 23 35 47)
stpiece if age>=23 & age<=32 & occ05==10, tp(0 11 23 35 47)
stpiece if age>=23 & age<=32 & occ05==11, tp(0 11 23 35 47)
stpiece if age>=23 & age<=32 & occ05==12, tp(0 11 23 35 47)
stpiece if age>=23 & age<=32 & occ05==13, tp(0 11 23 35 47)

* Table C1

/* 
We could have continued using the PCE model but uses the somewhat more flexible Cox model.
If we would use an even more flexible form of the baseline for the PCE model the estimates would come even closer. 
However, they are close already at this definition of 3 month intervals.
*/

gen t = _n
stset spell_weeks, failure(employed==1) id(t)

stcox male age punemp_month punemp_spells if occ_lev==1 & age>=23 & age<=32
stcox male age punemp_month punemp_spells if occ_lev==2 & age>=23 & age<=32
stcox male age punemp_month punemp_spells if occ_lev==3 & age>=23 & age<=32
stcox male age punemp_month punemp_spells if occ_lev==4 & age>=23 & age<=32

* Figure 3 in the article and Figure B1 in online Appendix B

/*
Truncating at spell_weeks==60 produce graphs with a time window relevant for the experiment. Most editing is done by hand in the graph editor.
*/

gen spell_weeks_60=spell_weeks
replace spell_weeks_60=60 if spell_weeks>=60

sts graph if age>=23 & age<=32, by(occ_lev) name(KM_occlev, replace) scheme(s1mono)

* Figure B2

sts graph if occ05_high==1 & age>=23 & age<=32, by(occ05) name(KM_occ_high, replace) scheme(s1mono)

* Figure B3

sts graph if occ05_high==2 & age>=23 & age<=32, by(occ05) name(KM_occ_medlow, replace) scheme(s1mono)


